Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4470)

Unified Diff: cc/surfaces/surface_manager.h

Issue 2802023002: Remove SurfaceFactory And SurfaceFactoryClient (Closed)
Patch Set: Change Ref/UnrefResources to public Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cc/surfaces/surface_manager.h
diff --git a/cc/surfaces/surface_manager.h b/cc/surfaces/surface_manager.h
index 4eaf993e759a167c5e03bebd43ea9395afeb77ee..db716bdd74da1965acc57e66f57ede33d76462d5 100644
--- a/cc/surfaces/surface_manager.h
+++ b/cc/surfaces/surface_manager.h
@@ -38,11 +38,9 @@ class BeginFrameSource;
class CompositorFrame;
class FrameSinkManagerClient;
class Surface;
-class SurfaceFactory;
-class SurfaceFactoryClient;
namespace test {
-class CompositorFrameSinkSupportTest;
+class SurfaceSynchronizationTest;
}
class CC_SURFACES_EXPORT SurfaceManager {
@@ -69,7 +67,7 @@ class CC_SURFACES_EXPORT SurfaceManager {
void RequestSurfaceResolution(Surface* pending_surface);
std::unique_ptr<Surface> CreateSurface(
- base::WeakPtr<SurfaceFactory> surface_factory,
+ base::WeakPtr<CompositorFrameSinkSupport> compositor_frame_sink_support,
const LocalSurfaceId& local_surface_id);
// Destroy the Surface once a set of sequence numbers has been satisfied.
@@ -85,8 +83,8 @@ class CC_SURFACES_EXPORT SurfaceManager {
bool SurfaceModified(const SurfaceId& surface_id);
// Called when a CompositorFrame is submitted to a SurfaceFactory for a given
// |surface_id| for the first time.
void SurfaceCreated(const SurfaceInfo& surface_info);
// Require that the given sequence number must be satisfied (using
@@ -104,8 +102,8 @@ class CC_SURFACES_EXPORT SurfaceManager {
// possibly because a renderer process has crashed.
void InvalidateFrameSinkId(const FrameSinkId& frame_sink_id);
// SurfaceFactoryClient, hierarchy, and BeginFrameSource can be registered
// and unregistered in any order with respect to each other.
//
// This happens in practice, e.g. the relationship to between ui::Compositor /
// DelegatedFrameHost is known before ui::Compositor has a surface/client).
@@ -172,7 +170,7 @@ class CC_SURFACES_EXPORT SurfaceManager {
}
private:
- friend class test::CompositorFrameSinkSupportTest;
+ friend class test::SurfaceSynchronizationTest;
friend class SurfaceManagerRefTest;
using SurfaceIdSet = std::unordered_set<SurfaceId, SurfaceIdHash>;
@@ -85,8 +83,8 @@ class CC_SURFACES_EXPORT SurfaceManager {
bool SurfaceModified(const SurfaceId& surface_id);
- // Called when a CompositorFrame is submitted to a SurfaceFactory for a given
- // |surface_id| for the first time.
+ // Called when a CompositorFrame is submitted to a CompositorFrameSinkSupport
+ // for a given |surface_id| for the first time.
void SurfaceCreated(const SurfaceInfo& surface_info);
// Require that the given sequence number must be satisfied (using
@@ -104,8 +102,8 @@ class CC_SURFACES_EXPORT SurfaceManager {
// possibly because a renderer process has crashed.
void InvalidateFrameSinkId(const FrameSinkId& frame_sink_id);
- // SurfaceFactoryClient, hierarchy, and BeginFrameSource can be registered
- // and unregistered in any order with respect to each other.
+ // CompositorFrameSinkSupport, hierarchy, and BeginFrameSource can be
+ // registered and unregistered in any order with respect to each other.
//
// This happens in practice, e.g. the relationship to between ui::Compositor /

Powered by Google App Engine
This is Rietveld 408576698